@@ -86,7 +86,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -139,6 +139,12 @@
 #else
 #  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x55900
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_89(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_89(text)
+#endif
 #define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -205,7 +211,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -215,7 +221,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -258,6 +264,12 @@
 #else
 #  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x55900
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_89(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_89(text)
+#endif
 #define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
