@@ -86,7 +86,7 @@
 #define KCONFIGQML_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGQML_NO_DEPRECATED
-#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KCONFIGQML_NO_DEPRECATED_WARNINGS
 #  define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -164,7 +164,7 @@
 #define KCONFIGQML_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGQML_NO_DEPRECATED
-#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KCONFIGQML_NO_DEPRECATED_WARNINGS
 #  define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0
@@ -174,7 +174,7 @@
 #  ifdef KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
